<div class="row ms-4 knowledge-nav-item cursor-pointer">
    <a
        class="col text-decoration-none text-app-default-text-color"
        {% if AuthController.knowledge.can_view %}
            :href="'{% url "django_spire:knowledge:entry:version:page:detail" pk=0 %}'.replace(0, entry.version_id)"
        {% endif %}
    >
        <i class="bi bi-file-earmark-text"></i>
        <span class="fw-normal" x-text="entry.name"></span>
    </a>
    {% if AuthController.knowledge.can_view %}
        <div class="col-auto">
            <div class="d-flex h-100 justify-content-center align-items-center">
                {% include 'django_spire/knowledge/navigation/item/entry/dropdown/navigation_ellipsis_dropdown.html' %}
            </div>
        </div>
    {% endif %}
</div>
