{% extends 'django_spire/card/title_card.html' %}

{% block card_title %}
    Notification List
{% endblock %}

{% block card_title_content %}
    {% for app_notification in notification_list %}
        {% include app_notification.template %}
    {% endfor %}
{% endblock %}
