# Generated by Django 5.2 on 2025-05-17 23:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_spire_ai_chat', '0002_remove_chatmessage_content_chatmessage__content_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='chatmessage',
            old_name='_content',
            new_name='_intel_data',
        ),
        migrations.RemoveField(
            model_name='chatmessage',
            name='_content_intel_class',
        ),
        migrations.AddField(
            model_name='chatmessage',
            name='_intel_class_name',
            field=models.TextField(default=''),
            preserve_default=False,
        ),
    ]
