{% extends 'django_spire/knowledge/navigation/page/full_page.html' %}

{% load static %}

{% block base_body_additional_top_js %}
    <script type="application/javascript" src="{% static 'django_spire/knowledge/entry/version/js/managers.js' %}?v={{ DJANGO_SPIRE_VERSION }}"></script>
{% endblock %}

{% block knowledge_full_page_content %}
    <style>
        .block {}

        .action-items {
            opacity: 0;
        }

        .block:hover .action-items {
            opacity: 1;
        }
    </style>
    <div class="row justify-content-center">
        <div class="col-12 col-xl-8">
            {% include 'django_spire/knowledge/entry/version/container/form_container.html' %}
        </div>
    </div>
{% endblock %}
