{% extends 'django_spire/page/page.html' %}

{% block page_content %}
    <div class="d-flex w-100 min-vh-100">
        <div class="pe-1 d-none d-lg-block side-navigation">
            {% block full_page_side_navigation %}
                {% include 'django_spire/navigation/side_navigation.html' %}
            {% endblock %}
        </div>

        <div class="d-flex flex-column container-fluid">
            <div class="row sticky-top">
                <div class="col-12 sticky-top">
                    {% block full_page_top_navigation %}
                        {% include 'django_spire/navigation/top_navigation.html' %}
                    {% endblock %}
                </div>
            </div>

            <div class="row flex-grow-1">
                <div class="col-12">
                    {% block full_page_content %}
                    {% endblock %}
                </div>
            </div>

            <div class="row">
                <div class="col-12 px-0 mt-2">
                    {% block full_page_bottom_content %}
                        {% include 'django_spire/footer/footer.html' %}
                    {% endblock %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}
