{% extends 'django_spire/card/card.html' %}

{% block card_padding %}
	px-0 py-3
{% endblock %}

{% block card_content %}
    {% include 'django_spire/knowledge/navigation/content/navigation_content.html' %}
{% endblock %}
