:root {
    --app-text-primary: var(--app-primary);
    --app-text-primary-soft: var(--app-primary-soft);
    --app-text-primary-dark: var(--app-primary-dark);

    --app-text-secondary: var(--app-secondary);
    --app-text-secondary-soft: var(--app-secondary-soft);
    --app-text-secondary-dark: var(--app-secondary-dark);

    --app-text-accent: var(--app-accent);
    --app-text-accent-soft: var(--app-accent-soft);
    --app-text-accent-dark: var(--app-accent-dark);

    --app-text-success: var(--app-success);
    --app-text-success-outlined: var(--app-success-soft);
    --app-text-success-dark: var(--app-success-dark);

    --app-text-warning: var(--app-warning);
    --app-text-warning-soft: var(--app-warning-soft);
    --app-text-warning-dark: var(--app-warning-dark);

    --app-text-danger: var(--app-danger);
    --app-text-danger-soft: var(--app-danger-soft);
    --app-text-danger-dark: var(--app-danger-dark);

    --app-text-layer-one: var(--app-layer-one);
    --app-text-layer-two: var(--app-layer-two);
    --app-text-layer-three: var(--app-layer-three);
    --app-text-layer-four: var(--app-layer-four);

    --app-text-alt-layer-one: var(--app-alt-layer-one);
    --app-text-alt-layer-two: var(--app-alt-layer-two);
    --app-text-alt-layer-three: var(--app-alt-layer-three);
    --app-text-alt-layer-four: var(--app-alt-layer-four);

    --app-text-side-navigation: var(--app-side-navigation-text-color);
    --app-link-side-navigation: var(--app-side-navigation-link-color);
    --app-link-side-navigation-hover: var(--app-side-navigation-link-hover-color);

    --app-text-top-navigation: var(--app-top-navigation-text-color);
    --app-link-top-navigation: var(--app-top-navigation-link-color);
    --app-link-top-navigation-hover: var(--app-top-navigation-link-hover-color);

    --app-text-footer: var(--app-footer-text-color);
    --app-link-footer: var(--app-footer-link-color);
    --app-link-footer-hover: var(--app-footer-link-hover-color);
}

.text-alt-color, .text-alt-color-hover:hover {
    color: var(--app-default-alt-text-color) !important;
}

.text-app-attribute-color, .text-app-attribute-color-hover:hover {
    color: var(--app-default-attribute-title-color) !important;
}

.text-app-default-link-color, .text-app-default-link-color:hover {
    color: var(--app-default-link-color) !important;
}

.text-app-default-text-color, .text-app-default-text-color:hover {
    color: var(--app-default-text-color) !important;
}

.text-app-primary, .text-app-primary-hover:hover {
    color: var(--app-text-primary) !important;
}

.text-app-primary-soft, .text-app-primary-soft-hover:hover {
    color: var(--app-text-primary-soft) !important;
}

.text-app-primary-dark, .text-app-primary-dark-hover:hover {
    color: var(--app-text-primary-dark) !important;
}

.text-app-secondary, .text-app-secondary-hover:hover {
    color: var(--app-text-secondary) !important;
}

.text-app-secondary-soft, .text-app-secondary-soft-hover:hover {
    color: var(--app-text-secondary-soft) !important;
}

.text-app-secondary-dark, .text-app-secondary-dark-hover:hover {
    color: var(--app-text-secondary-dark) !important;
}

.text-app-accent, .text-app-accent-hover:hover {
    color: var(--app-text-accent) !important;
}

.text-app-accent-soft, .text-app-accent-soft-hover:hover {
    color: var(--app-text-accent-soft) !important;
}

.text-app-accent-dark, .text-app-accent-dark-hover:hover {
    color: var(--app-text-accent-dark) !important;
}

.text-app-warning, .text-app-warning-hover:hover {
    color: var(--app-text-warning) !important;
}

.text-app-warning-soft, .text-app-warning-soft-hover:hover {
    color: var(--app-text-warning-soft) !important;
}

.text-app-warning-dark, .text-app-warning-dark-hover:hover {
    color: var(--app-text-warning-dark) !important;
}

.text-app-danger, .text-app-danger-hover:hover {
    color: var(--app-text-danger) !important;
}

.text-app-danger-soft, .text-app-danger-soft-hover:hover {
    color: var(--app-text-danger-soft) !important;
}

.text-app-danger-dark, .text-app-danger-dark-hover:hover {
    color: var(--app-text-danger-dark) !important;
}

.text-app-layer-one, .text-app-layer-one-hover:hover {
    color: var(--app-text-layer-one) !important;
}

.text-app-layer-two, .text-app-layer-one-hover:hover {
    color: var(--app-text-layer-two) !important;
}

.text-app-layer-three, .text-app-layer-three-hover:hover {
    color: var(--app-text-layer-three) !important;
}

.text-app-layer-four, .text-app-layer-four-hover:hover {
    color: var(--app-text-layer-four) !important;
}

.text-app-alt-layer-one, .text-app-alt-layer-one-hover:hover {
    color: var(--app-text-alt-layer-one) !important;
}

.text-app-alt-layer-two, .text-app-alt-layer-two-hover:hover {
    color: var(--app-text-alt-layer-two) !important;
}

.text-app-alt-layer-three, .text-app-alt-layer-three-hover:hover {
    color: var(--app-text-alt-layer-three) !important;
}

.text-app-alt-layer-four, .text-app-alt-layer-four-hover:hover {
    color: var(--app-text-alt-layer-four) !important;
}

.text-app-side-navigation {
    color: var(--app-text-side-navigation) !important;
}

.text-app-link-side-navigation {
    color: var(--app-link-side-navigation) !important;
}

.text-app-link-side-navigation:hover {
    color: var(--app-link-side-navigation-hover) !important;
}

.text-app-top-navigation {
    color: var(--app-text-top-navigation) !important;
}

.text-app-link-top-navigation {
    color: var(--app-link-top-navigation) !important;
}

.text-app-link-top-navigation:hover {
    color: var(--app-link-top-navigation-hover) !important;
}

.text-app-footer {
    color: var(--app-text-footer) !important;
}

.text-app-link-footer {
    color: var(--app-link-footer) !important;
}

.text-app-link-footer:hover {
    color: var(--app-link-footer-hover) !important;
}
